@@ -834,7 +834,7 @@ class ContainerSetting(Entity):
         self,
         container_name: Name,
         container_image: DockerImageName,
-        env_vars: Optional[ContainerEnvDict]=None,
+        env_vars: Optional[List[EnvVar]]=None,
         command: Optional[ContainerCommand]=None,
         args: Optional[ContainerArgs]=None,
         image_pull_policy: Optional[ImagePullPolicy]=ImagePullPolicy('Always'),
