@@ -342,6 +342,21 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
+    @exception_class_dec(max_try=1)
+    def delete_job(
+        self,
+        cluster_name:str,
+        namespace_name:str,
+        job_name:str,
+        timeout:int=10
+    ):
+        response=requests.get(
+            f'{self.url}/job/cluster_name/{cluster_name}/namespace_name/{namespace_name}/job_name/{job_name}', 
+            headers=self.header, timeout=timeout)
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
 
 repo_info = \
 {
